@@ -16,8 +16,10 @@ TIMEOUT = 240
 class NodeNetworkState(Resource):
     api_group = Resource.ApiGroup.NMSTATE_IO
 
-    def __init__(self, name, client=None, teardown=True):
-        super().__init__(name=name, client=client, teardown=teardown)
+    def __init__(self, name=None, client=None, teardown=True, yaml_file=None):
+        super().__init__(
+            name=name, client=client, teardown=teardown, yaml_file=yaml_file
+        )
         status = self.instance.to_dict()["status"]
         if "desiredState" in status:
             self.desired_state = status["desiredState"]
@@ -39,6 +41,9 @@ class NodeNetworkState(Resource):
 
     def to_dict(self):
         res = super().to_dict()
+        if self.yaml_file:
+            return res
+
         res.update(
             {
                 "spec": {
@@ -91,7 +96,7 @@ class NodeNetworkState(Resource):
 
     @property
     def interfaces(self):
-        return self.instance.to_dict()["status"]["currentState"]["interfaces"]
+        return self.instance.status.currentState.interfaces
 
     @property
     def routes(self):
